mir.monads
==========

.. image:: https://circleci.com/gh/project-mir/mir.monads.svg?style=shield
   :target: https://circleci.com/gh/project-mir/mir.monads
   :alt: CircleCI
.. image:: https://codecov.io/gh/project-mir/mir.monads/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/project-mir/mir.monads
   :alt: Codecov
.. image:: https://badge.fury.io/py/mir.monads.svg
   :target: https://badge.fury.io/py/mir.monads
   :alt: PyPi Release
.. image:: https://readthedocs.org/projects/mir-monads/badge/?version=latest
   :target: http://mir-monads.readthedocs.io/en/latest/
   :alt: Latest Documentation

Monads for Python.
